import { HttpClient } from '@angular/common/http';
import { Component, Inject, OnInit } from '@angular/core';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-create-image',
  templateUrl: './create-image.component.html',
  styleUrls: ['./create-image.component.css']
})
export class CreateImageComponent implements OnInit {
  name: string = '';
  downloads: any[] = [];
  selectedDownload: any;
  isEditMode: boolean = false;
  imageId: string | null = null;

  constructor(
    private toastService: ToastrService,
    private http: HttpClient,
    public dialogRef: MatDialogRef<CreateImageComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) { }

  ngOnInit(): void {
    this.fetchDownloads();
    if (this.data) {
      this.isEditMode = true;
      this.name = this.data.name;
      this.selectedDownload = this.data.downloadUrl;
      this.imageId = this.data.uuid;  // Assuming UUID is used for edit
    }
  }

  fetchDownloads(): void {
    this.http.get('http://127.0.0.1:8081/og-lives/server/get-isos?page=1&itemsPerPage=30')
      .subscribe({
        next: (response: any) => {
          this.downloads = response.data.downloads;
        },
        error: (error) => {
          console.error('Error fetching downloads:', error);
          this.toastService.error('Error fetching iso files');
        }
      });
  }

  onNoClick(): void {
    this.dialogRef.close();
  }

  submitForm(): void {
    const payload = {
      name: this.name,
      downloadUrl: this.selectedDownload.URL
    };

    if (this.isEditMode && this.imageId) {
      this.http.patch(`http://127.0.0.1:8081/og-lives/${this.imageId}`, payload)
        .subscribe({
          next: (response) => {
            this.toastService.success('Image updated successfully');
            this.dialogRef.close(true);
          },
          error: (error) => {
            console.error('Error:', error);
            this.toastService.error('Error updating image');
          }
        });
    } else {
      this.http.post('http://127.0.0.1:8081/og-lives', payload)
        .subscribe({
          next: (response) => {
            this.toastService.success('Image created successfully');
            this.dialogRef.close(true);
          },
          error: (error) => {
            console.error('Error:', error);
            this.toastService.error('Error creating image');
          }
        });
    }
  }
}
